# flake8: noqa

# import apis into api package
from wds_client.api.capabilities_api import CapabilitiesApi
from wds_client.api.collection_api import CollectionApi
from wds_client.api.general_wds_information_api import GeneralWDSInformationApi
from wds_client.api.import_api import ImportApi
from wds_client.api.job_api import JobApi
from wds_client.api.record_api import RecordApi
from wds_client.api.records_api import RecordsApi
from wds_client.api.schema_api import SchemaApi
from wds_client.api.workspace_api import WorkspaceApi




# coding: utf-8

"""
    Workspace Data Service

    This page lists current APIs.  All v0.2 APIs are subject to change without notice.  Changelog at [https://github.com/DataBiosphere/terra-workspace-data-service/releases](https://github.com/DataBiosphere/terra-workspace-data-service/releases) 

    The version of the OpenAPI document: v0.2
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from wds_client.api.schema_api import SchemaApi


class TestSchemaApi(unittest.TestCase):
    """SchemaApi unit test stubs"""

    def setUp(self) -> None:
        self.api = SchemaApi()

    def tearDown(self) -> None:
        pass

    def test_delete_attribute(self) -> None:
        """Test case for delete_attribute

        Delete attribute from record type
        """
        pass

    def test_delete_record_type(self) -> None:
        """Test case for delete_record_type

        Delete record type
        """
        pass

    def test_describe_all_record_types(self) -> None:
        """Test case for describe_all_record_types

        Describe all record types
        """
        pass

    def test_describe_record_type(self) -> None:
        """Test case for describe_record_type

        Describe record type
        """
        pass

    def test_update_attribute(self) -> None:
        """Test case for update_attribute

        Update an attribute
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Workspace Data Service

    This page lists current APIs.  All v0.2 APIs are subject to change without notice.  Changelog at [https://github.com/DataBiosphere/terra-workspace-data-service/releases](https://github.com/DataBiosphere/terra-workspace-data-service/releases) 

    The version of the OpenAPI document: v0.2
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from wds_client.models.version_response import VersionResponse

class TestVersionResponse(unittest.TestCase):
    """VersionResponse unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> VersionResponse:
        """Test VersionResponse
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `VersionResponse`
        """
        model = VersionResponse()
        if include_optional:
            return VersionResponse(
                app = wds_client.models.app.app(
                    chart_version = '', 
                    image = '', ),
                git = wds_client.models.git.git(
                    branch = '', 
                    commit = wds_client.models.commit.commit(
                        id = '', 
                        time = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), ), ),
                build = wds_client.models.build.build(
                    artifact = '', 
                    name = '', 
                    time = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                    version = '', 
                    group = '', )
            )
        else:
            return VersionResponse(
        )
        """

    def testVersionResponse(self):
        """Test VersionResponse"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Workspace Data Service

    This page lists current APIs.  All v0.2 APIs are subject to change without notice.  Changelog at [https://github.com/DataBiosphere/terra-workspace-data-service/releases](https://github.com/DataBiosphere/terra-workspace-data-service/releases) 

    The version of the OpenAPI document: v0.2
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from wds_client.models.collection import Collection

class TestCollection(unittest.TestCase):
    """Collection unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> Collection:
        """Test Collection
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `Collection`
        """
        model = Collection()
        if include_optional:
            return Collection(
                id = '',
                name = 'zBAMDTMv2D2ylmgd10Z3UB6UkJSISSB512iz2DiJykO4IVP7YNsKQHh9BsaMPOiOuo3_QLOpkBmKIPOf2Flbsh1TpRS00P',
                description = ''
            )
        else:
            return Collection(
                name = 'zBAMDTMv2D2ylmgd10Z3UB6UkJSISSB512iz2DiJykO4IVP7YNsKQHh9BsaMPOiOuo3_QLOpkBmKIPOf2Flbsh1TpRS00P',
                description = '',
        )
        """

    def testCollection(self):
        """Test Collection"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Workspace Data Service

    This page lists current APIs.  All v0.2 APIs are subject to change without notice.  Changelog at [https://github.com/DataBiosphere/terra-workspace-data-service/releases](https://github.com/DataBiosphere/terra-workspace-data-service/releases) 

    The version of the OpenAPI document: v0.2
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from wds_client.models.status_response import StatusResponse

class TestStatusResponse(unittest.TestCase):
    """StatusResponse unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> StatusResponse:
        """Test StatusResponse
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `StatusResponse`
        """
        model = StatusResponse()
        if include_optional:
            return StatusResponse(
                status = '',
                components = None
            )
        else:
            return StatusResponse(
        )
        """

    def testStatusResponse(self):
        """Test StatusResponse"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Workspace Data Service

    This page lists current APIs.  All v0.2 APIs are subject to change without notice.  Changelog at [https://github.com/DataBiosphere/terra-workspace-data-service/releases](https://github.com/DataBiosphere/terra-workspace-data-service/releases) 

    The version of the OpenAPI document: v0.2
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from wds_client.api.records_api import RecordsApi


class TestRecordsApi(unittest.TestCase):
    """RecordsApi unit test stubs"""

    def setUp(self) -> None:
        self.api = RecordsApi()

    def tearDown(self) -> None:
        pass

    def test_batch_write_records(self) -> None:
        """Test case for batch_write_records

        Batch write records
        """
        pass

    def test_create_or_replace_record(self) -> None:
        """Test case for create_or_replace_record

        Create or replace record
        """
        pass

    def test_delete_record(self) -> None:
        """Test case for delete_record

        Delete record
        """
        pass

    def test_get_record(self) -> None:
        """Test case for get_record

        Get record
        """
        pass

    def test_get_records_as_tsv(self) -> None:
        """Test case for get_records_as_tsv

        Retrieve all records in record type as tsv.
        """
        pass

    def test_query_records(self) -> None:
        """Test case for query_records

        Query records
        """
        pass

    def test_update_record(self) -> None:
        """Test case for update_record

        Update record
        """
        pass

    def test_upload_tsv(self) -> None:
        """Test case for upload_tsv

        Import records to a record type from a tsv file
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Workspace Data Service

    This page lists current APIs.  All v0.2 APIs are subject to change without notice.  Changelog at [https://github.com/DataBiosphere/terra-workspace-data-service/releases](https://github.com/DataBiosphere/terra-workspace-data-service/releases) 

    The version of the OpenAPI document: v0.2
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from wds_client.models.batch_operation import BatchOperation

class TestBatchOperation(unittest.TestCase):
    """BatchOperation unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> BatchOperation:
        """Test BatchOperation
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `BatchOperation`
        """
        model = BatchOperation()
        if include_optional:
            return BatchOperation(
                operation = 'upsert',
                record = wds_client.models.batch_record_request.BatchRecordRequest(
                    id = '', 
                    type = '', 
                    attributes = {
  "stringAttr": "string",
  "numericAttr": 123,
  "booleanAttr": true,
  "relationAttr": "terra-wds:/target-type/target-id",
  "fileAttr": "https://account_name.blob.core.windows.net/container-1/blob1",
  "arrayString": ["green", "red"],
  "arrayBoolean": [true, false],
  "arrayNumber": [12821.112, 0.12121211, 11],
  "arrayDate": ["2022-11-03"],
  "arrayDateTime": ["2022-11-03T04:36:20"],
  "arrayRelation": ["terra-wds:/target-type/target-id-1", "terra-wds:/target-type/target-id-2"],
  "arrayFile": ["drs://drs.example.org/file_id_1", "https://account_name.blob.core.windows.net/container-2/blob2"]
}
, )
            )
        else:
            return BatchOperation(
                operation = 'upsert',
                record = wds_client.models.batch_record_request.BatchRecordRequest(
                    id = '', 
                    type = '', 
                    attributes = {
  "stringAttr": "string",
  "numericAttr": 123,
  "booleanAttr": true,
  "relationAttr": "terra-wds:/target-type/target-id",
  "fileAttr": "https://account_name.blob.core.windows.net/container-1/blob1",
  "arrayString": ["green", "red"],
  "arrayBoolean": [true, false],
  "arrayNumber": [12821.112, 0.12121211, 11],
  "arrayDate": ["2022-11-03"],
  "arrayDateTime": ["2022-11-03T04:36:20"],
  "arrayRelation": ["terra-wds:/target-type/target-id-1", "terra-wds:/target-type/target-id-2"],
  "arrayFile": ["drs://drs.example.org/file_id_1", "https://account_name.blob.core.windows.net/container-2/blob2"]
}
, ),
        )
        """

    def testBatchOperation(self):
        """Test BatchOperation"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Workspace Data Service

    This page lists current APIs.  All v0.2 APIs are subject to change without notice.  Changelog at [https://github.com/DataBiosphere/terra-workspace-data-service/releases](https://github.com/DataBiosphere/terra-workspace-data-service/releases) 

    The version of the OpenAPI document: v0.2
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from setuptools import setup, find_packages  # noqa: H301

# To install the library, run the following
#
# python setup.py install
#
# prerequisite: setuptools
# http://pypi.python.org/pypi/setuptools
NAME = "wds-client"
VERSION = "0.38.37"
PYTHON_REQUIRES = ">=3.7"
REQUIRES = [
    "urllib3 >= 1.25.3, < 2.1.0",
    "python-dateutil",
    "pydantic >= 2",
    "typing-extensions >= 4.7.1",
]

setup(
    name=NAME,
    version=VERSION,
    description="Workspace Data Service",
    author="OpenAPI Generator community",
    author_email="team@openapitools.org",
    url="",
    keywords=["OpenAPI", "OpenAPI-Generator", "Workspace Data Service"],
    install_requires=REQUIRES,
    packages=find_packages(exclude=["test", "tests"]),
    include_package_data=True,
    license="BSD",
    long_description_content_type='text/markdown',
    long_description="""\
    This page lists current APIs.  All v0.2 APIs are subject to change without notice.  Changelog at [https://github.com/DataBiosphere/terra-workspace-data-service/releases](https://github.com/DataBiosphere/terra-workspace-data-service/releases) 
    """,  # noqa: E501
    package_data={"wds_client": ["py.typed"]},
)



# coding: utf-8

"""
    Workspace Data Service

    This page lists current APIs.  All v0.2 APIs are subject to change without notice.  Changelog at [https://github.com/DataBiosphere/terra-workspace-data-service/releases](https://github.com/DataBiosphere/terra-workspace-data-service/releases) 

    The version of the OpenAPI document: v0.2
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from wds_client.api.workspace_api import WorkspaceApi


class TestWorkspaceApi(unittest.TestCase):
    """WorkspaceApi unit test stubs"""

    def setUp(self) -> None:
        self.api = WorkspaceApi()

    def tearDown(self) -> None:
        pass

    def test_init_workspace_v1(self) -> None:
        """Test case for init_workspace_v1

        Initialize WDS for a given workspace.
        """
        pass


if __name__ == '__main__':
    unittest.main()
